clear all
set mem 50m
set more off
#delimit ;

* use a date (or any other text) to save the files with a different name than the ones provided 
* if no date is provided, the original log files will be overwritten
global date "22July013" ;

use "rain-democracy-data_17feb2013", clear ;

	capture log close ;
	log using "Rain-Democracy-Table-1", text replace ;

	************************************************************************************************************ ;
	* Table 1 - Sensitivity to changes in dependent variable ;
	************************************************************************************************************ ;
	
	* [1.1] BC original regression: ;


	ivreg2	polity_change 
		Iccode* Iccyear* time* 
		(lgdp_l2 =  lgpcp_l2)
		if BCsample==1,
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_1_1);
			
	test lgdp_l2=0 ;
	scalar chi2_1= r(chi2) ;
	scalar p_1=r(p) ;

	sum	polity_change if e(sample) ;
	scalar cv_polity = r(sd) / r(mean)	;
	
	outreg2 lgdp_l2 
		using "Table_1_$date.csv", replace
		se br bd(3) label
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, 
		Joint significance pval, p_1) ;

	* [1.2] Prezworski ;

	ivreg2	democracy_change 
		Iccode* Iccyear* time* 
		(lgdp_l2 =  lgpcp_l2)
		if BCsample==1,
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_1_2);
			
	test lgdp_l2=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	sum	democracy_change if e(sample) ;
	scalar cv_democracy = r(sd) / r(mean)	;
	
	outreg2 lgdp_l2 
		using "Table_1_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, 
		Joint significance pval, p_1) ;	
		

	* [1.3] Freedom House  - political rights;

	ivreg2	 change_polright 
		Iccode* Iccyear* time* 
		(lgdp_l2 =  lgpcp_l2)
		, /* we dont use BCSample==1 to use all observations used by BC in their appendix table */
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_1_3);
		sum change_polright ;
		scalar cv=r(sd)/r(mean);
		
		
	test lgdp_l2=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2
		using "Table_1_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, 
		Joint significance pval, p_1) ;	

	
	* [1.4] Geddes et al ;

	ivreg2	gwf_demchange 
		Iccode* Iccyear* time* 
		(lgdp_l2 =  lgpcp_l2)
		if BCsample==1,
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_1_5);
	sum gwf_demchange ;
	scalar cv=r(sd)/r(mean);
				
	test lgdp_l2=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 
		using "Table_1_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, 
		Joint significance pval, p_1) ;

	esttab rf_1_* using Table_1_RF_$date.csv, 
		order(lgpcp_l2)	
		replace star(* 0.10 ** 0.05 *** 0.01) se brackets scalars(F) ;		
		
	log close ;

	
	log using "Rain-Democracy-Table-2", text replace ;

	
	************************************************************************************************************ ;
	* Table 2 - Sensitivity to adding shocks in t-1 and t ;
	************************************************************************************************************ ;
		
	*******************************************" ;
	*** Table 2 column 1 ;	
	*******************************************" ;
	
	ivreg2	polity_change 
		Iccode* Iccyear* time* 
		(lgdp_l2 lgdp_l = lgpcp_l lgpcp_l2)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_2_1_1);

	test (lgdp_l=0) (lgdp_l2=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 lgdp_l 
		using "Table_2_$date.csv", replace
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;		


	*******************************************" ;
	*** Table 2 column 2 ;	
	*******************************************" ;
	
	ivreg2	democracy_change 
		Iccode* Iccyear* time* 
		(lgdp_l2 lgdp_l = lgpcp_l lgpcp_l2)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_2_2_1);

	test (lgdp_l=0) (lgdp_l2=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 lgdp_l 
		using "Table_2_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;



	*******************************************" ;
	*** Table 2 column 3 ;	
	*******************************************" ;
	
	ivreg2	change_polright 		
		Iccode* Iccyear* time* 
		(lgdp_l2 lgdp_l = lgpcp_l lgpcp_l2)
		,
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_2_3_1);

	test (lgdp_l=0) (lgdp_l2=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 lgdp_l 
		using "Table_2_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;		
		
	*******************************************" ;
	*** Table 2 column 4 ;	
	*******************************************" ;
	
	ivreg2	gwf_demchange 
		Iccode* Iccyear* time* 
		(lgdp_l2 lgdp_l = lgpcp_l lgpcp_l2)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_2_4_1);

	test (lgdp_l=0) (lgdp_l2=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 lgdp_l 
		using "Table_2_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
	
	esttab rf_2_* using Table_2_RF_$date.csv, 
		order(lgpcp_l2 lgpcp_l )	
		replace star(* 0.10 ** 0.05 *** 0.01) se brackets scalars(F) ;	
	
	log close ;
	

	log using "Rain-Democracy-Table-3", text replace ;

	

	************************************************************************************************************ ;
	* Table 3 - BC sample: original spec vs full spec ;
	************************************************************************************************************ ;
	
	* 1. BC data ;
	
	
	**************************************** ;
	* Table 3 column 1 ;
	**************************************** ;
	* [3.1] Run BC spec, original regression: ;

	ivreg2	polity_change 
		Iccode* Iccyear* time* 
		(lgdp_l2 =  lgpcp_l2)
		if BCsample==1,
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_3_1);
			
	test lgdp_l2=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 
		using "Table_3_$date.csv", replace
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, 
		Joint significance pval, p_1) ;

	**************************************** ;
	* Table 3 column 2;
	**************************************** ;	
	* [3.2] 3.1 + contemporaneous shocks: ;

	ivreg2	polity_change 
		Iccode* Iccyear* time* 
		(lgdp_l lgdp_l2 =  lgpcp_l lgpcp_l2)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*)  
		first rf saverf saverfprefix(rf_3_2);

	test (lgdp_l=0) (lgdp_l2=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 lgdp_l 
		using "Table_3_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
	**************************************** ;
	* Table 3 column 3;
	**************************************** ;	
	* 2 - updating GDP, original period (pwt 7.0);

	* [3.3] updating gdp (pwt 7.0) ;

	ivreg2	polity_change 
		Iccode* Iccyear* time* 
		(lgdp_l2_pwt70 =  lgpcp_l2)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_3_3);

	test lgdp_l2_pwt70=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 
		using "Table_3_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;

	**************************************** ;
	* Table 3 column 4;
	**************************************** ;
	* [3.4] 3.3 + contemporaneous shocks ; 
	
	ivreg2	polity_change 
		Iccode* Iccyear* time* 
		(lgdp_l_pwt70 lgdp_l2_pwt70 =  lgpcp_l lgpcp_l2)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_3_4);

	test (lgdp_l_pwt70=0) (lgdp_l2_pwt70=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 lgdp_l_pwt70 
		using "Table_3_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;

	**************************************** ;
	* Table 3 column 5;
	**************************************** ;	
	* 3 - updating everything, original period ;
	
	* [3.5] updating everything, BC spec ;

	ivreg2	polity_change_v2011 
		Iccode* Iccyear* time* 
		(lgdp_l2_pwt70 =  lgpcp_l2_v22)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_3_5);

	test lgdp_l2_pwt70=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 
		using "Table_3_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
	**************************************** ;
	* Table 3 column 6;
	**************************************** ;
	* [3.6] 3.5 + contemporaneous shocks ;

	ivreg2	polity_change_v2011 
		Iccode* Iccyear* time* 
		(lgdp_l_pwt70 lgdp_l2_pwt70 =  lgpcp_l_v22 lgpcp_l2_v22)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_3_6);

	test (lgdp_l_pwt70=0) (lgdp_l2_pwt70=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 lgdp_l_pwt70 
		using "Table_3_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;


	**************************************** ;
	* Table 3 column 7 ;
	**************************************** ;	
	* 4 - updating rainfall, original period ;

	* [3.7] updating rainfall (gpcp 2.2) ;

	ivreg2	polity_change 
		Iccode* Iccyear* time* 
		(lgdp_l2 =  lgpcp_l2_v22)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_3_7);

	test lgdp_l2=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 
		using "Table_3_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
	**************************************** ;
	* Table 3 column 8;
	**************************************** ;
	* [3.8] 1.7 + contemporaneous shocks ;

	ivreg2	polity_change 
		Iccode* Iccyear* time* 
		(lgdp_l lgdp_l2 =  lgpcp_l_v22 lgpcp_l2_v22)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_3_8);

	test (lgdp_l=0) (lgdp_l2=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 lgdp_l  
		using "Table_3_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
			
		
	**************************************** ;
	* Table 3 column 9;
	**************************************** ;
	* 5 - updating polity, original period ;	
	
	* [3.9] updating polity (version 2011) ;

	ivreg2	polity_change_v2011 
		Iccode* Iccyear* time* 
		(lgdp_l2 =  lgpcp_l2)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*)  
		first rf saverf saverfprefix(rf_3_9);
		
	test lgdp_l2=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 
		using "Table_3_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;

	**************************************** ;
	* Table 3 column 10;
	**************************************** ;
	* [3.10] 1.9 + contemporaneous shocks ;

	ivreg2	polity_change_v2011 
		Iccode* Iccyear* time* 
		(lgdp_l lgdp_l2 = lgpcp_l lgpcp_l2)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*)  
		first rf saverf saverfprefix(rf_3_10);

	test (lgdp_l=0) (lgdp_l2=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 lgdp_l  
		using "Table_3_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
	**************************************** ;
	* Table 3 column 11;
	**************************************** ;
	* 6. Updating everything, extending period until 2009 ;

	* [3.11] updating everything, BC spec ;

	ivreg2	polity_change_v2011 
		Iccode* Iccyear* time* 
		(lgdp_l2_pwt70 =  lgpcp_l2_v22)
		, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_3_11);

	test lgdp_l2_pwt70=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 
		using "Table_3_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
	**************************************** ;
	* Table 3 column 12;
	**************************************** ;
	* [3.12] 1.11 + contemporaneous shocks ;

	ivreg2	polity_change_v2011 
		Iccode* Iccyear* time* 
		(lgdp_l_pwt70 lgdp_l2_pwt70 =  lgpcp_l_v22 lgpcp_l2_v22)
		, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_3_12);

	test (lgdp_l_pwt70=0) (lgdp_l2_pwt70=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 lgdp_l_pwt70
		using "Table_3_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
	esttab rf_3_* using Table_3_RF_$date.csv, 
		order(lgpcp_l2 lgpcp_l lgpcp_l2_v22 lgpcp_l_v22)	
		replace star(* 0.10 ** 0.05 *** 0.01) se brackets scalars(F) ;		
	
	log close ;	


	*******************************************************************************************************************	;	
	* Tables 4-6 other democracy measures
	*******************************************************************************************************************	;
   
	local i = 4 ;
	while `i'<=6	{ ;
		if `i'==4 { ;
			local depvar="democracy_change";
		};
	
		if `i'==5 { ;
			local depvar="change_polright";
		};	
		
		if `i'==6 {;
			local depvar="gwf_demchange";
		};			


		log using "Rain-Democracy-Table-`i'", text replace ;

	
	*******************************************************************************************************************	;	
	* Table `i' - `depvvar' ;
	*******************************************************************************************************************	;	

	di "****************************************" ;
	di "Table `i' column 1" ;
	di "****************************************" ;	
	
	* [`i'.1] Run BC spec, original regression: ;

	ivreg2 `depvar'
		Iccode* Iccyear* time* 
		(lgdp_l2 =  lgpcp_l2)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_`i'_1);

	test lgdp_l2=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 
		using `"Table_`i'_$date.csv"', replace
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
	
	di "****************************************" ;
	di "Table `i' column 2" ;
	di "****************************************" ;	
	* [`i'.2] `i'.1 + contemporaneous shocks: ;

	ivreg2	`depvar'
		Iccode* Iccyear* time* 
		(lgdp_l lgdp_l2 =  lgpcp_l lgpcp_l2)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_`i'_2);

	test (lgdp_l=0) (lgdp_l2=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp lgdp_l lgdp_l2
		using "Table_`i'_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;


	di "****************************************" ;
	di "Table `i' column 3" ;
	di "****************************************" ;	
	* [`i'.3] updating gdp (pwt 7.0) ;

	ivreg2	`depvar'
		Iccode* Iccyear* time* 
		(lgdp_l2_pwt70 =  lgpcp_l2)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_`i'_3);

	test lgdp_l2_pwt70=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 
		using "Table_`i'_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;

	di "****************************************" ;
	di "Table `i' column 4" ;
	di "****************************************" ;	
	* [`i'.4] prev. col. + contemporaneous shocks ; 
	
	ivreg2	`depvar' 
		Iccode* Iccyear* time* 
		(lgdp_l2_pwt70 lgdp_l_pwt70 =  lgpcp_l2 lgpcp_l )
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_`i'_4);

	test (lgdp_l_pwt70=0) (lgdp_l2_pwt70=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 lgdp_l_pwt70 
		using "Table_`i'_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;


 	di "****************************************" ;
	di "Table `i' column 5" ;
	di "****************************************" ;	

	* [`i'.5] updating everything, BC spec ;

	ivreg2	`depvar' 
		Iccode* Iccyear* time* 
		(lgdp_l2_pwt70 =  lgpcp_l2_v22)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_`i'_5);

	test (lgdp_l2_pwt70=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 
		using "Table_`i'_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
	di "****************************************" ;
	di "Table `i' column 6" ;
	di "****************************************" ;	
	* [`i'.6] `i'.5 + contemporaneous shocks ;

	ivreg2	`depvar' 
		Iccode* Iccyear* time* 
		(lgdp_l_pwt70 lgdp_l2_pwt70 =  lgpcp_l_v22 lgpcp_l2_v22)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_`i'_6);

	test (lgdp_l_pwt70=0) (lgdp_l2_pwt70=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 lgdp_l_pwt70 
		using "Table_`i'_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
		
	di "****************************************" ;
	di "Table `i' column 7" ;
	di "****************************************" ;	
	* [`i'.7] updating rainfall (gpcp 2.2) ;

	ivreg2	`depvar' 
		Iccode* Iccyear* time* 
		(lgdp_l2 =  lgpcp_l2_v22)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_`i'_7);

	test lgdp_l2=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 
		using "Table_`i'_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
	di "****************************************" ;
	di "Table `i' column 8" ;
	di "****************************************" ;	
	* [`i'.8] `i'.7. + contemporaneous shocks ;

	ivreg2	`depvar' 
		Iccode* Iccyear* time* 
		(lgdp_l lgdp_l2 =  lgpcp_l_v22 lgpcp_l2_v22)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_`i'_8);

	test (lgdp_l=0) (lgdp_l2=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 lgdp_l 
		using "Table_`i'_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	

	di "****************************************" ;
	di "Table `i' column 9" ;
	di "****************************************" ;	
	* [`i'.9] updating everything, BC spec, 1981-2008 ;

	ivreg2	`depvar' 
		Iccode* Iccyear* time* 
		(lgdp_l2_pwt70 =  lgpcp_l2_v22)
		,
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_`i'_9);

	test lgdp_l2_pwt70=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 
		using "Table_`i'_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
	di "****************************************" ;
	di "Table `i' column 10" ;
	di "****************************************" ;	
	* [`i'.10] `i'.10 + contemporaneous shocks, 1981-2008  ;

	ivreg2	`depvar'
		Iccode* Iccyear* time* 
		(lgdp_l_pwt70 lgdp_l2_pwt70 =  lgpcp_l_v22 lgpcp_l2_v22)
		,
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_`i'_10);

	test (lgdp_l_pwt70=0) (lgdp_l2_pwt70=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 lgdp_l_pwt70 lgdp_pwt70 
		using "Table_`i'_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;		

	* Reduced Forms: ;
	esttab rf_`i'_* using Table_`i'_RF_$date.csv,
	order (lgpcp_l2 lgpcp_l lgpcp_l2_v22 lgpcp_l_v22) 
	replace star(* 0.10 ** 0.05 *** 0.01) se brackets scalars(F) ;
	
	log close ;
	
	local i = `i' + 1 ;
};
			
	log using "Rain-Democracy-Table-A1", text replace ;

	************************************************************************************************************ ;
	* Appendix Table 1 - "First Stage" ;
	************************************************************************************************************ ;

	#delimit ;
	**************************************** ;
	* Table A1 column 1 and 2;
	**************************************** ;	
	qui ivreg2	polity_change 
		Iccode* Iccyear* time* 
		(lgdp_l lgdp_l2 =  lgpcp_l lgpcp_l2)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) first;
	g insample_2=e(sample) ;
	
	xtreg lgdp_l lgpcp_l lgpcp_l2 Iccode* Iccyear* time* if insample_2==1, cluster(ccode) ;
	outreg2 lgpcp_l lgpcp_l2 using "Table_A1_$date.csv", se br replace ;

	xtreg lgdp_l2 lgpcp_l lgpcp_l2 Iccode* Iccyear* time* if insample_2==1, cluster(ccode) ;
	outreg2 lgpcp_l lgpcp_l2 using "Table_A1_$date.csv", se br append ;
	
	**************************************** ;
	* Table A1 column 3 and 4 ;
	**************************************** ;

	qui ivreg2	polity_change_v2011 
		Iccode* Iccyear* time* 
		(lgdp_l_pwt70 lgdp_l2_pwt70 =  lgpcp_l_v22 lgpcp_l2_v22)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) ;
	g insample_6=e(sample) ;
	
	
	xtreg lgdp_l_pwt70 lgpcp_l_v22 lgpcp_l2_v22 Iccode* Iccyear* time* if insample_6==1, cluster(ccode) ;
	outreg2 lgpcp_l_v22 lgpcp_l2_v22 using "Table_A1_$date.csv", se br append ;

	xtreg lgdp_l2_pwt70 lgpcp_l_v22 lgpcp_l2_v22 Iccode* Iccyear* time* if insample_6==1, cluster(ccode) ;
	outreg2 lgpcp_l_v22 lgpcp_l2_v22 using "Table_A1_$date.csv", se br append ;


	**************************************** ;
	* Table A1 column 5 and 6 ;
	**************************************** ;	

	qui	ivreg2	polity_change_v2011 
		Iccode* Iccyear* time* 
		(lgdp_l_pwt70 lgdp_l2_pwt70 =  lgpcp_l_v22 lgpcp_l2_v22)
		, 
		cluster(ccode) partial(Iccode* Iccyear* time*) ;
	g insample_12=e(sample) ;
	
	xtreg lgdp_l_pwt70 lgpcp_l_v22 lgpcp_l2_v22 Iccode* Iccyear* time* if insample_12==1, cluster(ccode) ;
	outreg2 lgpcp_l_v22 lgpcp_l2_v22 using "Table_A1_$date.csv", se br append ;

	xtreg lgdp_l2_pwt70 lgpcp_l_v22 lgpcp_l2_v22 Iccode* Iccyear* time* if insample_12==1, cluster(ccode) ;
	outreg2 lgpcp_l_v22 lgpcp_l2_v22 using "Table_A1_$date.csv", se br append ;

	log close ;
	

	log using "Rain-Democracy-Table-A2", text replace ;

	
	************************************************************************************************************ ;
	* Appendix Table 2 - Geddes et al data without inputation ;
	************************************************************************************************************ ;	

	
	**************************************** ;
	*** Table A2 column 1 ;
	**************************************** ;	
	
	* [A2.1] Run BC spec, original regression: ;

	ivreg2 gwf_demchange_original 
		Iccode* Iccyear* time* 
		(lgdp_l2 =  lgpcp_l2)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_A2_1);

	test lgdp_l2=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 
		using `"Table_A2_$date.csv"', replace
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
	
	**************************************** ;
	*** Table A2 column 2 ;
	**************************************** ;	

	* [A2.2] A2.1 + contemporaneous shocks: ;

	ivreg2	gwf_demchange_original
		Iccode* Iccyear* time* 
		(lgdp_l lgdp_l2 =  lgpcp_l lgpcp_l2)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_A2_2);

	test (lgdp_l=0) (lgdp_l2=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp lgdp_l lgdp_l2
		using "Table_A2_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;


	**************************************** ;
	*** Table A2 column 3 ;
	**************************************** ;	

	* [A2.3] updating gdp (pwt 7.0) ;

	ivreg2	gwf_demchange_original
		Iccode* Iccyear* time* 
		(lgdp_l2_pwt70 =  lgpcp_l2)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_A2_3);

	test lgdp_l2_pwt70=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 
		using "Table_A2_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;

	**************************************** ;
	*** Table A2 column 4 ;
	**************************************** ;	
	
	* [A2.4] prev. col. + contemporaneous shocks ; 
	
	ivreg2	gwf_demchange_original 
		Iccode* Iccyear* time* 
		(lgdp_l2_pwt70 lgdp_l_pwt70 =  lgpcp_l2 lgpcp_l )
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_A2_4);

	test (lgdp_l_pwt70=0) (lgdp_l2_pwt70=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 lgdp_l_pwt70 
		using "Table_A2_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;


	**************************************** ;
	*** Table A2 column 5 ;
	**************************************** ;	

	* [A2.5] updating everything, BC spec ;

	ivreg2	gwf_demchange_original
		Iccode* Iccyear* time* 
		(lgdp_l2_pwt70 =  lgpcp_l2_v22)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_A2_5);

	test (lgdp_l2_pwt70=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 
		using "Table_A2_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
	**************************************** ;
	*** Table A2 column 6 ;
	**************************************** ;	

	* [A2.6] A2.5 + contemporaneous shocks ;

	ivreg2	gwf_demchange_original
		Iccode* Iccyear* time* 
		(lgdp_l_pwt70 lgdp_l2_pwt70 =  lgpcp_l_v22 lgpcp_l2_v22)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_A2_6);

	test (lgdp_l_pwt70=0) (lgdp_l2_pwt70=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 lgdp_l_pwt70 
		using "Table_A2_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
		
	**************************************** ;
	*** Table A2 column 7 ;
	**************************************** ;	

	* [A2.7] updating rainfall (gpcp 2.2) ;

	ivreg2	gwf_demchange_original
		Iccode* Iccyear* time* 
		(lgdp_l2 =  lgpcp_l2_v22)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_A2_7);

	test lgdp_l2=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 
		using "Table_A2_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
	**************************************** ;
	*** Table A2 column 8 ;
	**************************************** ;	

	* [A2.8] A2.7. + contemporaneous shocks ;

	ivreg2	gwf_demchange_original 
		Iccode* Iccyear* time* 
		(lgdp_l lgdp_l2 =  lgpcp_l_v22 lgpcp_l2_v22)
		if BCsample==1, 
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_A2_8);

	test (lgdp_l=0) (lgdp_l2=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2 lgdp_l 
		using "Table_A2_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	

	**************************************** ;
	*** Table A2 column 9 ;
	**************************************** ;	

	* [A2.9] updating everything, BC spec, 1981-2008 ;

	ivreg2	gwf_demchange_original
		Iccode* Iccyear* time* 
		(lgdp_l2_pwt70 =  lgpcp_l2_v22)
		,
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_A2_9);

	test lgdp_l2_pwt70=0 ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 
		using "Table_A2_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;
	
	**************************************** ;
	*** Table A2 column 10 ;
	**************************************** ;	

	* [A2.10] ;

	ivreg2	gwf_demchange_original
		Iccode* Iccyear* time* 
		(lgdp_l_pwt70 lgdp_l2_pwt70 =  lgpcp_l_v22 lgpcp_l2_v22)
		,
		cluster(ccode) partial(Iccode* Iccyear* time*) 
		first rf saverf saverfprefix(rf_A2_10);

	test (lgdp_l_pwt70=0) (lgdp_l2_pwt70=0) ;
	scalar chi2_1 = r(chi2) ;
	scalar p_1=r(p) ;

	outreg2 lgdp_l2_pwt70 lgdp_l_pwt70 lgdp_pwt70 
		using "Table_A2_$date.csv", append
		se br bd(3) label 
		addstat( Anderson-Rubin chi2 pval, e(archi2p), Anderson-Rubin F pval, 
		e(arfp), Stock-Wright LM Chi pval, e(sstatp), Joint significance Chi2, chi2_1, Joint significance pval, p_1) ;		

	* Reduced Forms: ;
	esttab rf_A2_* using Table_A2_RF_$date.csv,
	order (lgpcp_l2 lgpcp_l lgpcp_l2_v22 lgpcp_l_v22) 
	replace star(* 0.10 ** 0.05 *** 0.01) se brackets scalars(F) ;
	
	log close ;
	

exit ;
